"""
Next Generation of django-jet (Modern template for Django admin interface with improved functionality)
"""

__version__ = '1.0.15'
__author__ = 'Geex Arts, Technology Innovation Network, Djungle Studio'
__license__ = 'AGPLv3'
__copyright__ = '2015-2018, Geex Arts. 2019-2020, Technology Innovation Network'
